@@ -21,17 +21,23 @@
 #include "config.h"
 #endif
 
+#include <sys/types.h>
 #include <grp.h>
 #include <pwd.h>
 #include <netdb.h>
 #include <rpc/types.h>
 #include <strings.h>
 #include <sys/socket.h>
+#include <sys/param.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <unistd.h>
 #include <ctype.h>
-#if defined(HAVE_GETOPT_H) && defined(HAVE_GETOPT_LONG)
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif /* HAVE_ALLOCA_H */
+#include <stdlib.h>
+#if defined(HAVE_GETOPT_H)
 #include <getopt.h>
 #endif
 #if defined(HAVE_LIBGDBM)
@@ -40,6 +46,7 @@
 #include <ndbm.h>
 #endif
 #include "yp.h"
+#include "compat.h"
 #include <rpcsvc/ypclnt.h>
 #include <arpa/nameser.h>
 #ifdef HAVE_SHADOW_H
@@ -178,7 +185,7 @@ print_hostname (char *param)
 	hp = gethostbyaddr (addr, sizeof (addr), AF_INET);
     }
   else
-    hp = gethostbyname2 (hostname, AF_INET);
+    hp = gethostbyname (hostname);
 
   if (hp == NULL)
     fputs (hostname, stdout);
@@ -197,7 +204,7 @@ print_maps (char *server, char *domain)
 #if USE_FQDN
   struct hostent *hp = NULL;
 #endif
-  char *master, *domainname;
+  char *master = NULL, *domainname;
   struct ypmaplist *ypmap = NULL, *y, *old;
   int ret;
 
@@ -219,7 +226,7 @@ print_maps (char *server, char *domain)
 	hp = gethostbyaddr (addr, sizeof (addr), AF_INET);
     }
   else
-    hp = gethostbyname2 (server, AF_INET);
+    hp = gethostbyname (server);
   if (hp != NULL)
     {
       server = alloca (strlen (hp->h_name) + 1);
@@ -312,6 +319,7 @@ merge_passwd (char *passwd, char *shadow)
 	  (pwd->pw_passwd[0] == 'x' || pwd->pw_passwd[0] == '*'))
 	{
 	  pass = NULL;
+#ifdef HAVE_GETSPNAM /* shadow password */
 	  spd = fgetspent (s_input);
 	  if (spd != NULL)
 	    {
@@ -330,6 +338,7 @@ merge_passwd (char *passwd, char *shadow)
 		    }
 		}
 	    }
+#endif /* HAVE_GETSPNAM */
 	  if (pass == NULL)
 	    pass = pwd->pw_passwd;
 	}
@@ -347,6 +356,7 @@ merge_passwd (char *passwd, char *shadow)
   exit (0);
 }
 
+#ifdef HAVE_GETSPNAM /* shadow password */
 static struct __sgrp *
 fgetsgent (FILE *fp)
 {
@@ -377,6 +387,7 @@ fgetsgent (FILE *fp)
     }
   return 0;
 }
+#endif /* HAVE_GETSPNAM */
 
 static void
 merge_group (char *group, char *gshadow)
@@ -421,6 +432,7 @@ merge_group (char *group, char *gshadow)
 	  (grp->gr_passwd[0] == 'x' || grp->gr_passwd[0] == '*'))
 	{
 	  pass = NULL;
+#ifdef HAVE_GETSPNAM /* shadow password */
 	  spd = fgetsgent (s_input);
 	  if (spd != NULL)
 	    {
@@ -439,6 +451,7 @@ merge_group (char *group, char *gshadow)
 		    }
 		}
 	    }
+#endif /* HAVE_GETSPNAM */
 	  if (pass == NULL)
 	    pass = grp->gr_passwd;
 	}
@@ -557,17 +570,20 @@ is_master (char *map, char *domain, char *host)
 	hp = gethostbyaddr (addr, sizeof (addr), AF_INET);
     }
   else
-    hp = gethostbyname2 (hostname, AF_INET);
+    hp = gethostbyname (hostname);
 
   if (hp != NULL)
-    hostname = strdupa (hp->h_name);
+    hostname = strdup (hp->h_name);
 #endif
 
   if (strcasecmp (hostname,
 		  get_dbm_entry ("YP_MASTER_NAME", map, domainname)) == 0)
-    exit (0);
+    ret = 0;
   else
-    exit (1);
+    ret = 1;
+
+  free(hostname);
+  exit (ret);
 }
 
 static void
