@@ -1,4 +1,4 @@
-/* Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 Thorsten Kukuk
+/* Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -44,6 +44,9 @@
 #include "log_msg.h"
 #include "ypserv_conf.h"
 #include "compat.h"
+#if USE_SLP
+#include "reg_slp.h"
+#endif
 
 #ifdef HAVE_PATHS_H
 #include <paths.h>
@@ -255,6 +258,7 @@ create_pidfile (void)
       log_msg ("cannot create pidfile %s", _YPSERV_PIDFILE);
       if (debug_flag)
 	log_msg ("\n");
+      return;
     }
 
   /* Make sure file gets correctly closed when process finished.  */
@@ -349,6 +353,10 @@ sig_quit (int sig UNUSED)
   pmap_unset (YPPROG, YPVERS);
   pmap_unset (YPPROG, YPOLDVERS);
   unlink (_YPSERV_PIDFILE);
+#if USE_SLP
+  if (slp_flag)
+    deregister_slp ();
+#endif
 
   exit (0);
 }
@@ -616,6 +624,11 @@ main (int argc, char **argv)
       exit (1);
     }
 
+#if USE_SLP
+  if (slp_flag)
+    register_slp ();
+#endif
+
 #if 0
   mysvc_run ();
 #else
@@ -623,6 +636,10 @@ main (int argc, char **argv)
 #endif
   log_msg ("svc_run returned");
   unlink (_YPSERV_PIDFILE);
+#if USE_SLP
+  if (slp_flag)
+    deregister_slp ();
+#endif
   exit (1);
   /* NOTREACHED */
 }
